- Fix bug #20: `xoutil.future.calendar`:mod: may fail at import time.

- Add `xoutil.params.pop_keyword_values`:func:.

- Add `xoutil.future.collections.codedict`:class:.  Deprecate module
  `xoutil.formatter`:mod:.
